pub struct VerificationKey {
pub key_id: String,
pub algorithm: SignatureAlgorithm,
pub public_key: String,
pub not_before: String,
pub not_after: Option<String>,
pub revoked_at: Option<String>,
pub purpose: Option<String>,
}Expand description
One of N public keys the platform may have used to sign records.
Fields
key_id: Stringalgorithm: SignatureAlgorithmpublic_key: Stringnot_before: Stringnot_after: Option<String>revoked_at: Option<String>purpose: Option<String>Trait Implementations
Sourceimpl Clone for VerificationKey
impl Clone for VerificationKey
Sourcefn clone(&self) -> VerificationKey
fn clone(&self) -> VerificationKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationKey
impl Debug for VerificationKey
Sourceimpl<'de> Deserialize<'de> for VerificationKey
impl<'de> Deserialize<'de> for VerificationKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationKey
Sourceimpl PartialEq for VerificationKey
impl PartialEq for VerificationKey
Sourcefn eq(&self, other: &VerificationKey) -> bool
fn eq(&self, other: &VerificationKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerificationKey
impl Serialize for VerificationKey
impl StructuralPartialEq for VerificationKey